@@ -18,6 +18,9 @@ from .const import (
     FSR_ENDPOINT_TOKEN,
     FSR_ENDPOINT_USER,
     FSR_ENDPOINT_MEMBERSHIPS,
+    FSR_ENDPOINT_SKILLS,
+    FSR_ENDPOINT_DUTY_STANDBY_FUNCTIONS,
+    FSR_ENDPOINT_DUTY_STANDBY_FUNCTION,
 )
 from .errors import FireServiceRotaError, InvalidAuthError, ExpiredTokenError, InvalidTokenError
 
@@ -103,6 +106,28 @@ class FireServiceRota(object):
         return response
 
 
+    def get_skills(self):
+        """Get skills."""
+
+        url = FSR_ENDPOINT_SKILLS
+
+        response = self._request('GET', endpoint=url, log_msg_action='get skills',
+                 auth_request=False)
+
+        return response
+
+
+    def get_standby_function(self, id):
+        """Get standby function."""
+
+        url = FSR_ENDPOINT_DUTY_STANDBY_FUNCTION.format(id)
+
+        response = self._request('GET', endpoint=url, log_msg_action='get standby function',
+                 auth_request=False)
+
+        return response
+
+
     def get_availability(self):
         """Get user availablity."""
 
@@ -122,16 +147,23 @@ class FireServiceRota(object):
           if interval['available'] == True:
             now = datetime.datetime.now().astimezone()
             if now > datetime.datetime.strptime(interval['start_time'], "%Y-%m-%dT%H:%M:%S.%f%z") and now < datetime.datetime.strptime(interval['end_time'], "%Y-%m-%dT%H:%M:%S.%f%z"):
-#               if 'comments' in interval:
-#                  print(interval['comments'])
-#               if 'exception' in interval:
-#                  print(interval['exception'])
-#               if 'recurring' in interval:
-#                  print(interval['recurring'])
+               if 'standby_duty' in interval['detailed_availability']:
+                   interval['type'] = 'standby_duty'
+               elif 'exception' in interval['detailed_availability']:
+                   interval['type'] = 'exception'
+               elif 'recurring' in interval['detailed_availability']:
+                   interval['type'] = 'recurring'
+               else:
+                   interval['type'] = 'unknown'
+
+               if interval['assigned_function_ids']:
+                   for func in interval['assigned_function_ids']:
+                       interval['assigned_function'] = self.get_standby_function(func)['name']
 
                return interval
 
-#        return False
+        interval['available'] = False
+        return interval
 
 
     def update(self):
